ver_mjr = R.Version()$major
ver_mnr = unlist(strsplit(R.Version()$minor,"\\."))[1]
lpath = sprintf("~/AppData/Local/R/win-library/%s.%s",ver_mjr,ver_mnr)
rversion = R.Version()
platform = Sys.info()['sysname']
print(sprintf("R version %s.%s running on %s",ver_mjr,ver_mnr,platform))
if(platform == "Windows") {
   if(!file.exists(lpath)) {
     dir.create(lpath,recursive=TRUE)
   }
   libpath <- c(lpath)
  .libPaths(libpath)
} else {
  libpath <- .libPaths()
  lpath <- .libPaths()
}

source('custom.R')

# load useful packages
load.libraries(c('psych','interactions','rio','tidyverse','afex','emmeans','lme4'),lpath)

#library(psych
#library(tidyverse)
#library(afex)
#library(emmeans)
#library(lme4)


# read data frame from RData format
load("data/all_data.Rda")


# describe your data
summary(d)

# descriptive statistics of selected variables
describe(d[,4:8])

# descriptive statistics of selected variables with FAST option
describe(d[,4:8], fast = TRUE)

# plot distribution of variable values with histogram
hist(d$aoi_fixation_average_duration_ms)

# plot distribution of variable values with boxplot
boxplot(d$aoi_fixation_average_duration_ms)


# Analysis of Variance (ANOVA)
# fixation count dependent on aoi valence and NEP score
fit <- aov_ez(data = d, 
              id = "ID", 
              dv = "aoi_fixation_average_duration_ms", 
              within = "aoi_type", 
              between = "NEPsplit")

# print basic ANOVA table
print(fit)

# print detailed ANOVA table
summary(fit)


# estimated means table for main effect
em <- emmeans(fit, ~aoi_type)
print(em)

# post-hoc for main effect
pairs(em)

# analytical graphs of main effect
emmip(fit, ~ aoi_type)

# estimated means table
em <- emmeans(fit, ~aoi_type:NEPsplit)
print(em)

# post-hoc tests (pairwise comparison) for interaction 

pairs(em, by = "NEPsplit")
pairs(em, by = "aoi_type")

# analytical graphs of interaction
emmip(fit,  NEPsplit ~ aoi_type)


# publication ready graph of interaction
tab <- summary(em)

plo <- ggplot(tab, aes(x=aoi_type, y=emmean, fill=NEPsplit)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL),
                width=.2, position=position_dodge(.9)) +
  scale_y_continuous(name = "Average fixation duration (ms.)") +
  scale_x_discrete(name = "AOI type",
                   labels = c("neutral", "negative", "positive")) +
  scale_fill_manual(name = "NEP", 
                    values=c("#999999", "#E69F00")) +
  theme_minimal()

# save the graph
print(plo)
ggsave(plot = plo, filename = "graphs/AverageFixationDuration_NEP_AOI.jpg")
dev.off()


# fixation count on different AOI by NEP split
fit <- aov_ez(data = d, 
              id = "ID", 
              dv = "aoi_fixation_total_count", 
              within = "aoi_type", 
              between = "NEPsplit")
# print basic ANOVA table
print(fit)

# estimated means for main effect
em <- emmeans(fit, ~aoi_type)
print(em)

# post-hoc tests (pairwise comparison) for interaction 
pairs(em)

# analytical graph for main effect
emmip(fit, ~aoi_type)

# publication ready graph of interaction
tab <- summary(em)

plo <- ggplot(tab, aes(x=aoi_type, y=emmean)) + 
  geom_bar(position=position_dodge(), stat="identity") +
  geom_errorbar(aes(ymin=emmean-SE, ymax=emmean+SE),
                width=.2, position=position_dodge(.9)) +
  scale_y_continuous(name = "Average fixation duration (ms.)") +
  scale_x_discrete(name = "AOI type", 
                   labels = c("neutral", "negative", "positive")) +
  theme_minimal()

# save the graph
print(plo)
ggsave(plot = plo, filename = "graphs/fixationCount_AOI.jpg")
dev.off()


# REGRESSION ANALYSIS
require(lme4)

# for average fixation duration

# a linear mixed effects model model with just a random intercept
fit <- lmer(aoi_fixation_average_duration_ms ~ NEP*aoi_type + (1 | ID), 
            data = d)

# longer form of model definition
fit <- lmer(aoi_fixation_average_duration_ms ~ NEP + aoi_type + NEP:aoi_type + (1 | ID), 
            data = d)

# see the results
anova(fit)
summary(fit)

# trends analysis for interaction
em <- emtrends(fit, ~ NEP:aoi_type, var = "NEP")
print(em)
pairs(em)

plo <- emmip(fit, aoi_type ~ NEP, cov.reduce = range) +
        geom_line(size=1.5) +
        scale_y_continuous(name = "Average fixation duration (ms.)") +
        scale_x_continuous(name = "NEP") +
        scale_color_manual(name = "AOI type", 
                           labels = c("neutral", "negative", "positive"), 
                           values = c("#E69F00", "#0000FF", "#FF00FF")) +
        theme_minimal() +
        theme(legend.position = c(.85, .5))

print(plo)
ggsave(plot = plo, filename = "graphs/fixationDuration_regression.jpg")
dev.off()

# for fixation count
# a linear mixed effects model model with just a random intercept
fit <- lmer(aoi_fixation_total_count ~ NEP*aoi_type + (1 | ID), data = d)
anova(fit)
summary(fit)

(em <- emtrends(fit, ~ NEP:aoi_type, var = "NEP"))
pairs(em)

plo <- emmip(fit, aoi_type ~ NEP, cov.reduce = range) +
        geom_line(size=1.5) +
        scale_y_continuous(name = "Fixation count") +
        scale_x_continuous(name = "NEP") +
        scale_color_manual(name = "AOI type", labels = c("neutral", "negative", "positive"),
                     values = c("#E69F00", "#0000FF", "#FF00FF")) +
        theme_minimal() +
        theme(legend.position = c(.85, .5))

print(plo)
ggsave(plot = plo, filename = "graphs/fixationCount_regression.jpg")
dev.off()


# alternativelly
require(interactions)
interact_plot(fit, pred = NEP, modx = aoi_type, interval = TRUE) +
  scale_y_continuous(name = "Fixation count") +
  scale_x_continuous(name = "NEP") +
  theme_minimal() +
  theme(legend.position = c(.5, .1))
